require "xelnex/version"
require "pty"
require "timeout"

module Xelnex
  class Handler
    attr_accessor :timeout

    def handle(input)
      if connected
        send_line(input)
      else
        connect!(input)
        send_line("")
      end
    end

    def print(results)
      puts results
    end

    private

    attr_accessor :connected, :send_con, :recv_con

    def connect!(server)
      master, slave = PTY.open
      read, write = IO.pipe
      pid = spawn("telnet #{server}", in: read, out: slave)
      read.close
      slave.close

      self.send_con = write
      self.recv_con = master
      self.connected = true
    end

    def send_line(line)
      send_con.puts line unless line.empty?

      "".tap do |result|
        begin
          loop do
            Timeout::timeout(self.timeout || 0.1) do
              ans = recv_con.gets
              result << ans
            end
          end
        rescue Timeout::Error
        end
      end
    end
  end
end
